@@ -1,6 +1,7 @@
 from enum import Enum
 
 GRAPH_BASE_URL = "https://graph.microsoft.com"
+GRAPH_CONSENT_URL = "https://login.microsoftonline.com"
 V1_EP = "/v1.0"
 BETA_EP = "/beta"
 
@@ -14,6 +15,7 @@ SEARCH = "search"
 USERS = "/users"
 SUBSCRIPTIONS = "/subscriptions"
 MAILS = "/messages"
+SENDMAIL = "/sendmail"
 GROUPS = "/groups"
 SITES = "/sites"
 DRIVE = "/drive"
